<?php

namespace PAE\Util;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Teknisa\Libs\Service\Menu as MenuService;
use Teknisa\Libs\Factory\Menu as MenuFactory;
use Zeedhi\Framework\DataSource\DataSet;

class MenuController {
    
    protected $menuFactory;

    public function __construct(MenuFactory $menuFactory) {
        $this->menuFactory = $menuFactory;
    }

    public function leituraMenuPMEePAE(Request\Filter $request, Response $response) {
        $menuService = new MenuService($this->menuFactory);
        $params = $request->getFilterCriteria()->getConditions();
            
        $concatenateGroupMenu = $this->getValueInFilterDataSourceByName($params, 'CONCATENATE_GROUP_MENU');
        $visibleMenus = $this->getValueInFilterDataSourceByName($params, 'VISIBLE_ELEMENTS');
        $expiredMenus = $this->getValueInFilterDataSourceByName($params, 'EXPIRED_ELEMENTS');
        $urlOrigin = $this->getValueInFilterDataSourceByName($params, 'URL_ORIGIN');
        $menus = $menuService->buildMenu($concatenateGroupMenu, $visibleMenus, $expiredMenus, $urlOrigin, 'product', 'pt_br');
        
        // Adicionar menus do PME Next       
        array_push($menus['MENUS'], $this->getMenuPME());
        
        $response->addDataSet(new DataSet('menu', $menus['MENUS']));
    }

    /**
     * @param array[] $filters
     * @param $nameFilter
     * @param bool $remove
     * @return null
     */
    private function getValueInFilterDataSourceByName(array &$filters,$nameFilter,$remove = false)
    {
        foreach ($filters as $key => $filter) {
            $name = $filter['columnName'];
            $values = $filter['value'];
            if($name == $nameFilter ){
                if($remove){
                    unset($filters[$key]);
                }
                return $values;
            }
        }
        return null;
    }
    
    /*
    Ajustar função para pegar menu dinamicamente no PME Next.
    */
    private function getMenuPME(){
        $json = '
        [
            {
                "id": "520973934936932015764",
                "name": "inicio",
                "label": "Início",
                "devOpsId": 6935,
                "isVisible": true
            },
            {
                "id": "5209739344210156022597",
                "name": "elaboracao_cardapio",
                "isVisible": true,
                "label": "Elaboração do Cardápio",
                "devOpsId": 6935
            },
            {
                "id": "5209739342086820050598",
                "name": "emissao_cardapio_periodo",
                "isVisible": true,
                "label": "Emissão do Cardápio do Período",
                "devOpsId": 6935
            },
            {
                "id": "5209739341402015972599",
                "name": "consumo_por_servico",
                "isVisible": true,
                "label": "Consumo por Serviço",
                "devOpsId": 6935
            },
            {
                "id": "5209739342378527769600",
                "name": "requisicao_servico_analitico",
                "isVisible": true,
                "label": "Requisição por Serviço Analítica",
                "devOpsId": 6935
            },
            {
                "id": "5209739343511555649601",
                "name": "retirada_inventario",
                "isVisible": true,
                "label": "Retirada do Merenda com Base no Inventário",
                "devOpsId": 6935
            },
            {
                "id": "5209739341949695113602",
                "name": "efetivos",
                "isVisible": true,
                "label": "Efetivos",
                "devOpsId": 6935
            },
            {
                "id": "5209739343499688293628",
                "name": "parametrizacao",
                "label": "Parametrização",
                "isVisible": true,
                "items": [
                    {
                        "id": "5209739344130347209637",
                        "name": "parametrizacao_PLA",
                        "component": "ZdMenuGroup",
                        "icon": "mdi-book-open-variant",
                        "label": "Planejamento",
                        "cssClass": "menu-padding",
                        "items": [
                            {
                                "id": "5209739341870357603638",
                                "name": "ger96000_central",
                                "label": "Central",
                                "isVisible": true,
                                "route": "/ger96000_central",
                                "devOpsId": 6935
                            },
                            {
                                "id": "5209739342598018725135",
                                "name": "pla05600_ponto_entrega",
                                "label": "Ponto de Entrega",
                                "isVisible": true,
                                "route": "/pla05600_ponto_entrega",
                                "devOpsId": 6935
                            },
                            {
                                "id": "520973934329822797353",
                                "name": "ger01800_unidade_de_medida",
                                "label": "Unidade de Medida",
                                "isVisible": true,
                                "route": "/ger01800_unidade_de_medida",
                                "devOpsId": 6935
                            },
                            {
                                "id": "52097393498297303258",
                                "name": "embalgem_PLA",
                                "component": "ZdMenuGroup",
                                "label": "Embalagem",
                                "cssClass": "menu-padding",
                                "items": [
                                    {
                                        "id": "520973934303821940259",
                                        "name": "pla15300_categoria_embalagens",
                                        "label": "Categoria",
                                        "isVisible": true,
                                        "route": "/pla15300_categoria_embalagens",
                                        "devOpsId": 6935
                                    },
                                    {
                                        "id": "5209739341921795255260",
                                        "name": "pla00470_embalagem",
                                        "label": "Embalagem",
                                        "isVisible": true,
                                        "route": "/pla00470_embalagem",
                                        "devOpsId": 6935
                                    }
                                ],
                                "devOpsId": 6935,
                                "isVisible": true
                            },
                            {
                                "id": "5209739341327986412795",
                                "name": "prato",
                                "component": "ZdMenuGroup",
                                "label": "Prato",
                                "items": [
                                    {
                                        "id": "5209739342963954517463",
                                        "name": "pla01400_tipo_de_prato",
                                        "label": "Tipo de Prato",
                                        "route": "/pla01400_tipo_de_prato",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    },
                                    {
                                        "id": "5209739341401591282623",
                                        "name": "pla01300_prato",
                                        "label": "Prato",
                                        "route": "/pla01300_prato",
                                        "isVisible": true,
                                        "devOpsId": 6935
                                    },
                                    {
                                        "id": "520973934192182339639",
                                        "name": "ger21000_formas_apresentacao",
                                        "label": "Formas de Apresentação",
                                        "route": "/ger21000_formas_apresentacao",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    },
                                    {
                                        "id": "52097393486764769258",
                                        "name": "dih52300_medicao_caseira",
                                        "label": "Medição Caseira",
                                        "route": "/dih52300_medicao_caseira",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    },
                                    {
                                        "id": "5209739341738683719259",
                                        "name": "pla15100_formas_de_preparo",
                                        "label": "Formas de Preparo",
                                        "route": "/pla15100_formas_de_preparo",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    }
                                ],
                                "devOpsId": 6935,
                                "isVisible": true
                            },
                            {
                                "id": "520973934381673572854",
                                "name": "produto",
                                "component": "ZdMenuGroup",
                                "label": "Produto",
                                "items": [
                                    {
                                        "id": "520973934308601768937",
                                        "name": "ger01000_unidade_adicional_produto",
                                        "label": "Unidade Adicional do Produto",
                                        "route": "/ger01000_unidade_adicional_produto",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    },
                                    {
                                        "id": "52097393424418102755",
                                        "name": "ger22000_apresentacao_produto",
                                        "label": "Apresentação do Produto",
                                        "route": "/ger22000_apresentacao_produto",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    }
                                ],
                                "devOpsId": 6935,
                                "isVisible": true
                            },
                            {
                                "id": "5209739342479152728644",
                                "name": "servico",
                                "component": "ZdMenuGroup",
                                "label": "Serviço",
                                "isVisible": true,
                                "items": [
                                    {
                                        "id": "520973934805005748646",
                                        "name": "padrao_de_servico",
                                        "label": "Padrão de Serviço",
                                        "route": "/ger30000_padrao_de_servico",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    }
                                ],
                                "devOpsId": 6935
                            },
                            {
                                "id": "5209739342895818602647",
                                "name": "nutrientes",
                                "component": "ZdMenuGroup",
                                "label": "Nutrientes",
                                "isVisible": true,
                                "items": [
                                    {
                                        "id": "5209739344103438707649",
                                        "name": "nutrientes",
                                        "label": "Nutriente",
                                        "route": "/ger02500_nutrientes",
                                        "devOpsId": 6935,
                                        "isVisible": true
                                    }
                                ],
                                "devOpsId": 6935
                            },
                            {
                                "id": "5209739343863042986797",
                                "name": "nutrientesPorProd",
                                "label": "Nutrientes por Produto",
                                "route": "/ger04000_nutrientes_por_produto",
                                "devOpsId": 6935,
                                "isVisible": true
                            },
                            {
                                "id": "5209739343918907664651",
                                "name": "nutricionista",
                                "label": "Nutricionista",
                                "route": "/ger80500_nutricionista",
                                "devOpsId": 6935,
                                "isVisible": true
                            },
                            {
                                "id": "520973934192182339643",
                                "name": "ger28000_tipo_de_retirada",
                                "label": "Tipo de Retirada",
                                "route": "/ger28000_tipo_de_retirada",
                                "devOpsId": 6935,
                                "isVisible": true
                            },
                            {
                                "id": "5209739343918907664652",
                                "name": "parametros",
                                "label": "Parâmetros",
                                "isVisible": true,
                                "route": "/pla01900_parametros_de_planejamento",
                                "devOpsId": 6935
                            }
                        ],
                        "devOpsId": 6935,
                        "isVisible": true
                    }
                ]
            }
        ]';
            	
        return json_decode($json, true);
    }
} 