/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: 8961_SUPFUNS_CALCULA_DATAEMBARQUE_OL.sql

Descrio:
Clcula a data de embarque para um determinado item de pedido do operador
logstico

Criao:
09/03/2007 Marcelo Alexsandro Souza Silva
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CALCULA_DATAEMBARQUE_OL' AND
                 TYPE = 'FN' 		       AND
	              U.UID = O.UID            AND
	              U.NAME = USER)
DROP FUNCTION CALCULA_DATAEMBARQUE_OL
GO
CREATE FUNCTION CALCULA_DATAEMBARQUE_OL(
   @P_CDFILIOPELOG VARCHAR(4),
   @P_CDFILIAL     VARCHAR(4),
   @P_CDARVPROD    VARCHAR(20),
   @P_DTENTREGA    DATETIME) RETURNS DATETIME
AS
BEGIN
   DECLARE   @V_NRLIMISEGU   NUMERIC(5);
   DECLARE   @V_NRCONTA      NUMERIC(5);

   DECLARE   @V_DTENTREGA         DATETIME;
   DECLARE   @V_ENTREGA_MENOS_ANO DATETIME;
   DECLARE   @V_ENTREGA_MENOS_DIA DATETIME;

   DECLARE   @V_CONTAUXI     INT;

   DECLARE   @V_IDDNULIMSEG  VARCHAR(1);
   DECLARE   @W_N            VARCHAR(1);
   DECLARE   @W_S            VARCHAR(1);
   SET @W_N = 'N';
   SET @W_S = 'S';

   SET @V_ENTREGA_MENOS_ANO = CONVERT(DATETIME, @P_DTENTREGA - 364);
   SET @V_ENTREGA_MENOS_DIA = CONVERT(DATETIME, @P_DTENTREGA - 1);
   SET @V_NRLIMISEGU        = 0;
   SET @V_DTENTREGA         = @P_DTENTREGA;

   SELECT @V_NRLIMISEGU  = ISNULL(MAX(CONVERT(NUMERIC, NRDIAEMBARQUE)),0),
          @V_IDDNULIMSEG = ISNULL(MAX(IDSOMENTEUTIL), @W_S)
   FROM DATAEMBARQUEOL, PRODUTO
   WHERE DATAEMBARQUEOL.CDPRODUTO    = PRODUTO.CDPRODUTO
     AND DATAEMBARQUEOL.CDFILIAL     = @P_CDFILIAL
     AND DATAEMBARQUEOL.CDFILIOPELOG = @P_CDFILIOPELOG
     AND PRODUTO.CDARVPROD = (SELECT MAX(CDARVPROD)
                              FROM DATAEMBARQUEOL A, PRODUTO B
                              WHERE A.CDFILIAL     = @P_CDFILIAL
                                AND A.CDFILIOPELOG = @P_CDFILIOPELOG
                                AND A.CDPRODUTO    = B.CDPRODUTO
                                AND CHARINDEX(B.CDARVPROD, @P_CDARVPROD) = 1);

   IF @V_NRLIMISEGU > 0 BEGIN
   /* Cursor com dias teis no intervalo de um ano a partir da data de entrega */
      DECLARE C_MAIORDATA CURSOR FOR
         SELECT
            DTDATA
         FROM
            DATA
         WHERE (DTDATA BETWEEN @V_ENTREGA_MENOS_ANO AND @V_ENTREGA_MENOS_DIA)
           AND ((@V_IDDNULIMSEG = @W_N) OR ((@V_IDDNULIMSEG = @W_S)
           AND (DTDATA NOT IN (SELECT
                                  DTFERICOMP
                               FROM
                                  FERICOMP
                               WHERE (CDFILIAL   = @P_CDFILIOPELOG)
                                 AND (DTFERICOMP < @P_DTENTREGA)))))
          ORDER BY
             DTDATA DESC;
      OPEN C_MAIORDATA;
      SET @V_NRCONTA = 1;
      WHILE @V_NRCONTA <= @V_NRLIMISEGU BEGIN
         /* Busca a ltima data ate o n de dias para embarque */
         FETCH NEXT FROM C_MAIORDATA INTO @V_DTENTREGA;
         IF @@FETCH_STATUS <> 0 BEGIN
            BREAK;
         END;
         SET @V_NRCONTA = @V_NRCONTA + 1;
      END;
      CLOSE      C_MAIORDATA;
      DEALLOCATE C_MAIORDATA;
   END;

   IF @V_IDDNULIMSEG = @W_S BEGIN
      SET @V_CONTAUXI = 1;
   END;
   
   WHILE @V_CONTAUXI > 0 BEGIN
     SELECT @V_CONTAUXI = COUNT(*)
     FROM FERICOMP
     WHERE CDFILIAL   = @P_CDFILIOPELOG
       AND DTFERICOMP = @V_DTENTREGA;
     IF @V_CONTAUXI > 0 BEGIN
        SET @V_DTENTREGA = @V_DTENTREGA - 1;
     END;
   END;
   RETURN(@V_DTENTREGA);
END
GO

-- VERSAO --
EXEC ATUVEROBJ 'CALCULA_DATAEMBARQUE_OL','4.11.081';
GO
